# JupyterLab console example

This example demonstrates how to create an application displaying a code console (similar to IPython console) and a list of commands.

![preview](./example.spec.ts-snapshots/example-linux.png)
